Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(784)

Unified Diff: runtime/vm/assembler_x64.cc

Issue 11412106: Support VTune's JIT interface. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/assembler_x64.h ('k') | runtime/vm/code_observers.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/assembler_x64.cc
diff --git a/runtime/vm/assembler_x64.cc b/runtime/vm/assembler_x64.cc
index 57ffd01ab83883ee4d981bacc8095f40305124c8..04feed85925a56dfce8e8274dc7289c60a832ca3 100644
--- a/runtime/vm/assembler_x64.cc
+++ b/runtime/vm/assembler_x64.cc
@@ -328,7 +328,7 @@ void Assembler::movq(Register dst, const Immediate& imm) {
// Use 0x89 encoding (instead of 0x8B encoding), which is expected by gdb64
// older than 7.3.1-gg5 when disassembling a function's prolog (movq rbp, rsp)
// for proper unwinding of Dart frames (use --generate_gdb_symbols and -O0).
void Assembler::movq(Register dst, Register src) {
AssemblerBuffer::EnsureCapacity ensured(&buffer_);
@@ -1799,8 +1799,8 @@ void Assembler::Bind(Label* label) {
void Assembler::EnterFrame(intptr_t frame_size) {
- if (prolog_offset_ == -1) {
- prolog_offset_ = CodeSize();
+ if (prologue_offset_ == -1) {
+ prologue_offset_ = CodeSize();
}
pushq(RBP);
movq(RBP, RSP);
@@ -328,7 +328,7 @@ void Assembler::movq(Register dst, const Immediate& imm) {
// Use 0x89 encoding (instead of 0x8B encoding), which is expected by gdb64
-// older than 7.3.1-gg5 when disassembling a function's prolog (movq rbp, rsp)
+// older than 7.3.1-gg5 when disassembling a function's prologue (movq rbp, rsp)
// for proper unwinding of Dart frames (use --generate_gdb_symbols and -O0).
void Assembler::movq(Register dst, Register src) {
« no previous file with comments | « runtime/vm/assembler_x64.h ('k') | runtime/vm/code_observers.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698